@@ -1,9 +1,11 @@
 ljr1 <- function(y,n,tm,X=NULL,ofst=0,summ=TRUE)
 {
    N=length(y)
-   m=ncol(X)
-   if (is.null(m)) 
+   if (is.null(X)) 
     m=0
+   else
+    m=ncol(X)
+   or.ofst=ofst
    if (length(ofst)==1)
     ofst=as.double(rep(ofst,N))
    else
@@ -26,7 +28,7 @@ ljr1 <- function(y,n,tm,X=NULL,ofst=0,summ=TRUE)
    for (i in 1:length(out$tau))
     t.variables=c(t.variables,paste('max(t-tau',i,',0)',sep=""))
    if (summ==TRUE)
-    if ((ofst[1]==0)&(length(ofst)==1))
+    if ((or.ofst[1]==0)&(length(or.ofst)==1))
      cat('eta=b0')
     else
      cat('eta=ofst+b0')
@@ -34,10 +36,8 @@ ljr1 <- function(y,n,tm,X=NULL,ofst=0,summ=TRUE)
     if (length(m.variables)>1)
      for (i in 2:length(m.variables))
       cat(paste(paste('+b',i-1,sep=""),'*',m.variables[i],sep=""))
-    for (i in 2:length(m.variables))
-     cat(paste(paste('+b',i-1,sep=""),'*',m.variables[i],sep=""))
-    for (i in 0:(length(t.variables)-1))
-     cat(paste(paste('+g',i,sep=""),'*',t.variables[i+1],sep=""))
+     for (i in 0:(length(t.variables)-1))
+      cat(paste(paste('+g',i,sep=""),'*',t.variables[i+1],sep=""))
     cat("\n\n")
    }
    m.coef=c(out$beta,out$gamma)   
