@@ -4,6 +4,7 @@ ljrkk <- function(k,y,n,tm,X=NULL,ofst=0,R=1000)
  m=ncol(X)
  if (is.null(m)) 
   m=0
+ or.ofst=ofst
  if (length(ofst)==1)
   ofst=as.double(rep(ofst,N))
  else
@@ -26,7 +27,7 @@ ljrkk <- function(k,y,n,tm,X=NULL,ofst=0,R=1000)
  t.variables='t'
  for (i in 1:k)
   t.variables=c(t.variables,paste('max(t-tau',i,',0)',sep=""))
- if ((ofst[1]==0)&(length(ofst)==1))
+ if ((or.ofst[1]==0)&(length(or.ofst)==1))
   cat('eta=b0')
  else
   cat('eta=ofst+b0')
